==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/EwidencjaPokoje.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class EwidencjaPokoje extends GenericDPSObject {
    /**
     * EWIDENCJA_POKOJE.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * EWIDENCJA_POKOJE.DPS_POKOJ_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long dpsPokojId;

    /**
     * EWIDENCJA_POKOJE.EWIDENCJA_DPS_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long ewidencjaDpsId;

    /**
     * EWIDENCJA_POKOJE.POPRZEDNI_POKOJ_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long poprzedniPokojId;

    /**
     * EWIDENCJA_POKOJE.DATA_OD
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataOd;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return EWIDENCJA_POKOJE.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * EWIDENCJA_POKOJE.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return EWIDENCJA_POKOJE.DPS_POKOJ_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getDpsPokojId() {
        return dpsPokojId;
    }

    /**
     * EWIDENCJA_POKOJE.DPS_POKOJ_ID
     *
     * @param dpsPokojId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDpsPokojId(Long dpsPokojId) {
        this.dpsPokojId = dpsPokojId;
    }

    /**
     * @return EWIDENCJA_POKOJE.EWIDENCJA_DPS_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getEwidencjaDpsId() {
        return ewidencjaDpsId;
    }

    /**
     * EWIDENCJA_POKOJE.EWIDENCJA_DPS_ID
     *
     * @param ewidencjaDpsId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setEwidencjaDpsId(Long ewidencjaDpsId) {
        this.ewidencjaDpsId = ewidencjaDpsId;
    }

    /**
     * @return EWIDENCJA_POKOJE.POPRZEDNI_POKOJ_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPoprzedniPokojId() {
        return poprzedniPokojId;
    }

    /**
     * EWIDENCJA_POKOJE.POPRZEDNI_POKOJ_ID
     *
     * @param poprzedniPokojId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPoprzedniPokojId(Long poprzedniPokojId) {
        this.poprzedniPokojId = poprzedniPokojId;
    }

    /**
     * @return EWIDENCJA_POKOJE.DATA_OD
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataOd() {
        return dataOd;
    }

    /**
     * EWIDENCJA_POKOJE.DATA_OD
     *
     * @param dataOd
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataOd(Date dataOd) {
        this.dataOd = dataOd;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        EwidencjaPokoje other = (EwidencjaPokoje) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getDpsPokojId() == null ? other.getDpsPokojId() == null : this.getDpsPokojId().equals(other.getDpsPokojId()))
            && (this.getEwidencjaDpsId() == null ? other.getEwidencjaDpsId() == null : this.getEwidencjaDpsId().equals(other.getEwidencjaDpsId()))
            && (this.getPoprzedniPokojId() == null ? other.getPoprzedniPokojId() == null : this.getPoprzedniPokojId().equals(other.getPoprzedniPokojId()))
            && (this.getDataOd() == null ? other.getDataOd() == null : this.getDataOd().equals(other.getDataOd()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getDpsPokojId() == null) ? 0 : getDpsPokojId().hashCode());
        result = prime * result + ((getEwidencjaDpsId() == null) ? 0 : getEwidencjaDpsId().hashCode());
        result = prime * result + ((getPoprzedniPokojId() == null) ? 0 : getPoprzedniPokojId().hashCode());
        result = prime * result + ((getDataOd() == null) ? 0 : getDataOd().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", dpsPokojId=").append(dpsPokojId);
        sb.append(", ewidencjaDpsId=").append(ewidencjaDpsId);
        sb.append(", poprzedniPokojId=").append(poprzedniPokojId);
        sb.append(", dataOd=").append(dataOd);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/EwidencjaPokoje.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class EwidencjaPokoje extends GenericDPSObject {
    /**
     * EWIDENCJA_POKOJE.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * EWIDENCJA_POKOJE.DPS_POKOJ_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long dpsPokojId;

    /**
     * EWIDENCJA_POKOJE.EWIDENCJA_DPS_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long ewidencjaDpsId;

    /**
     * EWIDENCJA_POKOJE.POPRZEDNI_POKOJ_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long poprzedniPokojId;

    /**
     * EWIDENCJA_POKOJE.DATA_OD
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataOd;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return EWIDENCJA_POKOJE.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * EWIDENCJA_POKOJE.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return EWIDENCJA_POKOJE.DPS_POKOJ_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getDpsPokojId() {
        return dpsPokojId;
    }

    /**
     * EWIDENCJA_POKOJE.DPS_POKOJ_ID
     *
     * @param dpsPokojId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDpsPokojId(Long dpsPokojId) {
        this.dpsPokojId = dpsPokojId;
    }

    /**
     * @return EWIDENCJA_POKOJE.EWIDENCJA_DPS_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getEwidencjaDpsId() {
        return ewidencjaDpsId;
    }

    /**
     * EWIDENCJA_POKOJE.EWIDENCJA_DPS_ID
     *
     * @param ewidencjaDpsId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setEwidencjaDpsId(Long ewidencjaDpsId) {
        this.ewidencjaDpsId = ewidencjaDpsId;
    }

    /**
     * @return EWIDENCJA_POKOJE.POPRZEDNI_POKOJ_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPoprzedniPokojId() {
        return poprzedniPokojId;
    }

    /**
     * EWIDENCJA_POKOJE.POPRZEDNI_POKOJ_ID
     *
     * @param poprzedniPokojId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPoprzedniPokojId(Long poprzedniPokojId) {
        this.poprzedniPokojId = poprzedniPokojId;
    }

    /**
     * @return EWIDENCJA_POKOJE.DATA_OD
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataOd() {
        return dataOd;
    }

    /**
     * EWIDENCJA_POKOJE.DATA_OD
     *
     * @param dataOd
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataOd(Date dataOd) {
        this.dataOd = dataOd;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        EwidencjaPokoje other = (EwidencjaPokoje) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getDpsPokojId() == null ? other.getDpsPokojId() == null : this.getDpsPokojId().equals(other.getDpsPokojId()))
            && (this.getEwidencjaDpsId() == null ? other.getEwidencjaDpsId() == null : this.getEwidencjaDpsId().equals(other.getEwidencjaDpsId()))
            && (this.getPoprzedniPokojId() == null ? other.getPoprzedniPokojId() == null : this.getPoprzedniPokojId().equals(other.getPoprzedniPokojId()))
            && (this.getDataOd() == null ? other.getDataOd() == null : this.getDataOd().equals(other.getDataOd()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getDpsPokojId() == null) ? 0 : getDpsPokojId().hashCode());
        result = prime * result + ((getEwidencjaDpsId() == null) ? 0 : getEwidencjaDpsId().hashCode());
        result = prime * result + ((getPoprzedniPokojId() == null) ? 0 : getPoprzedniPokojId().hashCode());
        result = prime * result + ((getDataOd() == null) ? 0 : getDataOd().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", dpsPokojId=").append(dpsPokojId);
        sb.append(", ewidencjaDpsId=").append(ewidencjaDpsId);
        sb.append(", poprzedniPokojId=").append(poprzedniPokojId);
        sb.append(", dataOd=").append(dataOd);
        sb.append("]");
        return sb.toString();
    }
}
